Test upload package
===================

PyPi: https://pypi.org/project/twizvolcano/

สวัสดีจ้าาาา แพ็คนี้คือแพ็คเกจที่อธิบายโปรไฟล์ของนาย Wizvolcano

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install twizvolcano

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from volcano import Wizvolcano

       vc = Wizvolcano()
       vc.show_name()
       vc.about()
       vc.show_art()

By: Wizvolcano
